# S2IPythonResponseS2i

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**thoth_s2i** | **str** | Full qualifier of Thoth&#x27;s s2i. |
**thoth_s2i_image_name** | **str** | Name of the Thoth s2i. | [optional]
**thoth_s2i_image_version** | **str** | Version of the Thoth s2i. | [optional]
**analysis_id** | **str** | Container image analysis id. |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
